summaryrefslogtreecommitdiffstats
path: root/tdecore/network/kresolver.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:48:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:48:49 -0600
commit13281e2856a2ef43bbab78c5528470309c23aa77 (patch)
tree936bcf8145dc235004c73e9fb3d6b3dca9aa370b /tdecore/network/kresolver.h
parente81c741bb2cf337a43524e75f22f7728ce17a343 (diff)
downloadtdelibs-13281e2856a2ef43bbab78c5528470309c23aa77.tar.gz
tdelibs-13281e2856a2ef43bbab78c5528470309c23aa77.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'tdecore/network/kresolver.h')
-rw-r--r--tdecore/network/kresolver.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/tdecore/network/kresolver.h b/tdecore/network/kresolver.h
index 1b13d676b..e2e08623b 100644
--- a/tdecore/network/kresolver.h
+++ b/tdecore/network/kresolver.h
@@ -796,11 +796,11 @@ public:
* Note that the encoding is illegible and, thus, should not be presented
* to the user, except if requested.
*
* @param tqunicodeDomain the domain name to be encoded
* @return the ACE-encoded suitable for DNS queries if successful, a null
* TQCString if failure.
*/
- static TQCString domainToAscii(const TQString& tqunicodeDomain);
+ static TQCString domainToAscii(const TQString& unicodeDomain);
/**
* Does the inverse of @ref domainToAscii and return an Unicode domain
@@ -796,11 +796,11 @@ public:
* to the user, except if requested.
*
- * @param tqunicodeDomain the domain name to be encoded
+ * @param unicodeDomain the domain name to be encoded
* @return the ACE-encoded suitable for DNS queries if successful, a null
* TQCString if failure.